
/* ESP-now Property Bell - Transmitter WEMOS D1 mini with PIR
 * Markus Opitz, August 2022 
 * https://www.instructables.com/Property-Bell/
 */

#if defined(ESP8266)
  #include <ESP8266WiFi.h>
#elif defined(ESP32)
  #include <WiFi.h>
#endif

#include <espnow.h>
int counter = 0;

// REPLACE WITH RECEIVER MAC Address
uint8_t broadcastAddress[] = {0xEC, 0xFA, 0xBC, 0x5F, 0x0A, 0x91};
//example   EC:FA:BC:5F:0A:91

// Structure example to send data must match the receiver structure
typedef struct struct_message {
  char a[32];
  int b;

} struct_message;

// Create a struct_message called myData
struct_message myData;

unsigned long lastTime = 0;  
unsigned long timerDelay = 2000;  // send readings timer


// Callback when data is sent  -  -  -  -  -  -  -  -  -  -  -  -  -  -
void OnDataSent(uint8_t *mac_addr, uint8_t sendStatus) {
  Serial.print("Last Packet Send Status: ");
  if (sendStatus == 0){
    Serial.println("Delivery success");
    
    Serial.println("Go to sleep now");
    delay(100);
    ESP.deepSleep(0);
  }
  else{
    Serial.println("Delivery fail");
    counter++;
    if (counter > 4) {    //retry four times
      counter = 0;
      Serial.println("go to sleep without success");
      ESP.deepSleep(0);
    }
    
  }
}
 
void setup() {
  Serial.begin(115200);

  Serial.println("");Serial.println("");
  Serial.println("just woke up: ALARM");Serial.println("");

  // Set device as a Wi-Fi Station
  WiFi.mode(WIFI_STA);

  // Init ESP-NOW
  if (esp_now_init() != 0) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }

  // Once ESPNow is successfully Init, we will register for Send CB to
  // get the status of Trasnmitted packet
  esp_now_set_self_role(ESP_NOW_ROLE_CONTROLLER);
  esp_now_register_send_cb(OnDataSent);
  
  // Register peer
  esp_now_add_peer(broadcastAddress, ESP_NOW_ROLE_SLAVE, 1, NULL, 0);
}
 
void loop() {

  
  if ((millis() - lastTime) > timerDelay) {

    // Set values to send
    strcpy(myData.a, "Alarm");
      myData.b = 4376;  //just a number, must match with 'Bell-Receiver.ino'

    // Send message via ESP-NOW
    esp_now_send(broadcastAddress, (uint8_t *) &myData, sizeof(myData));

    lastTime = millis();

  }
}
